@@ -51,7 +51,12 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.8";
+use Date::Format;
+use Date::Parse;
+
+
+
+our $VERSION = "5.0.9";
 
 
 =head2 on_initiate
@@ -98,8 +103,11 @@ sub on_initiate
                                        config => $config
                                      );
 
+        my $x = $data->{ 'posted' };
+        my $date = time2str( "%e %B %Y", $x );
+
         push( @$entries,
-              {  date  => $data->{ 'date_only' },
+              {  date  => $date,
                  title => $data->{ 'title' },
                  link  => $data->{ 'link' },
                  tags  => $data->{ 'tags' },
